#include "..\script_component.hpp"

/*
 * Function: ramdb_db_fnc_hashDeleteId
 * Author: Creedcoder, J.Schmidt
 * Edit: 07.15.2024
 * Copyright © 2024 Creedcoder, J.Schmidt, All rights reserved
 *
 * Do not edit without permission!
 *
 * This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 * To view a copy of this license, vist https://creativecommons.org/licenses/by-nc-sa/4.0/ or send a letter to Creative Commons,
 * PO Box 1866, Mountain View, CA 94042
 *
 * [Description]
 * Remove hash table from DB.
 *
 * Arguments:
 * 0: Name of stored hash table <STRING> (default: "")
 *
 * Return Value:
 * N/A
 *
 * Examples:
 * ["myKey"] call ramdb_db_fnc_hashDeleteId (Server or Singleplayer Only)
 * ["myKey"] remoteExecCall ["ramdb_db_fnc_hashDeleteId", 2, false] (Multiplayer Only)
 *
 * Public: Yes
 */

params [["_key", "", [""]]];

#ifdef __A3__DEBUG__
    diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashDeleteId' Key: '%1'", _key];
#endif

if (_key == "") exitWith {
    diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashDeleteId' Invalid Input for Key '%1'", _key];
};

"ArmaRAMDb" callExtension ["hdelid", [_key]];